## Hypothesis Validation

### Question

This is the question we're trying to answer:

```text
{question}
```

### Current Hypothesis

This is the hypothesis we're working on

{current_hypothesis}

### Current Test

This is the current test we're working on

{current_test}

### Team

To answer this question we have assembled the following team:

{team_description}

### Collected Evidence

Here is the evidence we have collected so far:

{evidence}

### Issues

Here is the list of issues we have encountered during our work:

{issues}
